| Title: | Generic Validations |
|---|---|
| Description: | Generic set of Validations and Exceptions used by most packages. |
| Authors: | Flippie Coetser [aut, cre] (ORCID: <https://orcid.org/0000-0003-0549-9245>) |
| Maintainer: | Flippie Coetser <[email protected]> |
| License: | file LICENSE |
| Version: | 0.0.1.0001 |
| Built: | 2026-05-17 06:11:35 UTC |
| Source: | https://github.com/FlippieCoetser/Validate |
Validator which returns a generic set of validators and accompanied exceptions.
a list value:
input |> validate[['is.not.NULL']](argument)
input |> validate[['is.data.frame']]()
input |> validate[['is.character']]()
input |> validate[['is.empty']]()
input |> validate[['is.not.empty']]()
input |> validate[['has.one.row']]()
input |> validate[['is.UUID']](identifier)